# Test Coverage Report

Generated: Fri 2015-09-11 18:53 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 240 | 199 | 41 | 100.0%
frequently.__init__ | 1 | 0 | 1 | 100.0%
frequently.forms | 44 | 37 | 7 | 100.0%
frequently.models | 49 | 34 | 15 | 100.0%
frequently.templatetags.frequently_tags | 10 | 8 | 2 | 100.0%
frequently.views | 136 | 120 | 16 | 100.0%

Excluded packages and modules
Error packages and modules